Plugin: JS9Sync

### JS9 Sync Images

Synchronize two or more images, so that when an operation is performed on one image, it also is performed on the other(s). For example, when the colormap or scale is changed on an image, it also is changed on the sync'ed images. Or, when a region is created, moved, resized, or removed on an image, the same happens on the sync'ed images. You also can synchronize once only.

The plugin displays a list of images that can be sync'ed with the current image, as well as a list of operations that can be sync'ed, including "colormap", "contrast/bias", "flip", "pan", "regions", "rot90", "scale", "wcs sys/units", and "zoom". Choose one or more images to sync and one or more operations for sync'ing and then click Sync Repeatedly" or Sync Once. The first routine calls JS9.SyncImages() while the second calls JS9.CopyParams() to perform repeated or single synchronizing, respectively. You also can Unsync operations that previously had been set up for repeated synchronization.

Upon initialization, the displayed images and ops checkboxes will show both images and operations sync'ed with the currently displayed image. When you execute a new repeated synchronization, the displayed checkboxes will be updated appropriately. Note that if you synchronize once only, the display will not reflect this one-time action (but will continue to reflect repeated synchronizations, if any). This makes it clear which images and ops are repeatedly sync'ed and thus makes it easier to unsync operations.

The following options are available:

- reciprocal sync : images sync one another (i.e., changes go both ways)
- sync using wcs: use wcs header params to sync (e.g. for pan), where available